==> libLAS-1.6.0b4.tar.gz: libLAS-1.6.0b4/src/CMakeFiles/las.dir/cmake_clean.cmake <==
FILE(REMOVE_RECURSE
  "CMakeFiles/las.dir/detail/index/indexcell.cpp.o"
  "CMakeFiles/las.dir/detail/index/indexoutput.cpp.o"
  "CMakeFiles/las.dir/chipper.cpp.o"
  "CMakeFiles/las.dir/factory.cpp.o"
  "CMakeFiles/las.dir/classification.cpp.o"
  "CMakeFiles/las.dir/color.cpp.o"
  "CMakeFiles/las.dir/dimension.cpp.o"
  "CMakeFiles/las.dir/error.cpp.o"
  "CMakeFiles/las.dir/filter.cpp.o"
  "CMakeFiles/las.dir/header.cpp.o"
  "CMakeFiles/las.dir/index.cpp.o"
  "CMakeFiles/las.dir/point.cpp.o"
  "CMakeFiles/las.dir/reader.cpp.o"
  "CMakeFiles/las.dir/spatialreference.cpp.o"
  "CMakeFiles/las.dir/schema.cpp.o"
  "CMakeFiles/las.dir/transform.cpp.o"
  "CMakeFiles/las.dir/utility.cpp.o"
  "CMakeFiles/las.dir/variablerecord.cpp.o"
  "CMakeFiles/las.dir/writer.cpp.o"
  "CMakeFiles/las.dir/version.cpp.o"
  "CMakeFiles/las.dir/detail/utility.cpp.o"
  "CMakeFiles/las.dir/detail/zippoint.cpp.o"
  "CMakeFiles/las.dir/detail/reader/header.cpp.o"
  "CMakeFiles/las.dir/detail/reader/reader.cpp.o"
  "CMakeFiles/las.dir/detail/reader/zipreader.cpp.o"
  "CMakeFiles/las.dir/detail/reader/cachedreader.cpp.o"
  "CMakeFiles/las.dir/detail/writer/base.cpp.o"
  "CMakeFiles/las.dir/detail/writer/header.cpp.o"
  "CMakeFiles/las.dir/detail/writer/point.cpp.o"
  "CMakeFiles/las.dir/detail/writer/zipwriter.cpp.o"
  "CMakeFiles/las.dir/detail/writer/writer.cpp.o"
  "../bin/Debug/liblas.pdb"
  "../bin/Debug/liblas.dylib"
  "../bin/Debug/liblas.2.0.0.dylib"
)

# Per-language clean rules from dependency scanning.
FOREACH(lang CXX)
  INCLUDE(CMakeFiles/las.dir/cmake_clean_${lang}.cmake OPTIONAL)
ENDFOREACH(lang)

==> libLAS-1.6.1.tar.gz: libLAS-1.6.1/src/CMakeFiles/las.dir/cmake_clean.cmake <==
FILE(REMOVE_RECURSE
  "CMakeFiles/las.dir/detail/index/indexcell.cpp.o"
  "CMakeFiles/las.dir/detail/index/indexoutput.cpp.o"
  "CMakeFiles/las.dir/chipper.cpp.o"
  "CMakeFiles/las.dir/factory.cpp.o"
  "CMakeFiles/las.dir/classification.cpp.o"
  "CMakeFiles/las.dir/color.cpp.o"
  "CMakeFiles/las.dir/dimension.cpp.o"
  "CMakeFiles/las.dir/error.cpp.o"
  "CMakeFiles/las.dir/filter.cpp.o"
  "CMakeFiles/las.dir/header.cpp.o"
  "CMakeFiles/las.dir/index.cpp.o"
  "CMakeFiles/las.dir/point.cpp.o"
  "CMakeFiles/las.dir/reader.cpp.o"
  "CMakeFiles/las.dir/spatialreference.cpp.o"
  "CMakeFiles/las.dir/schema.cpp.o"
  "CMakeFiles/las.dir/transform.cpp.o"
  "CMakeFiles/las.dir/utility.cpp.o"
  "CMakeFiles/las.dir/variablerecord.cpp.o"
  "CMakeFiles/las.dir/writer.cpp.o"
  "CMakeFiles/las.dir/version.cpp.o"
  "CMakeFiles/las.dir/detail/utility.cpp.o"
  "CMakeFiles/las.dir/detail/zippoint.cpp.o"
  "CMakeFiles/las.dir/detail/reader/header.cpp.o"
  "CMakeFiles/las.dir/detail/reader/reader.cpp.o"
  "CMakeFiles/las.dir/detail/reader/zipreader.cpp.o"
  "CMakeFiles/las.dir/detail/reader/cachedreader.cpp.o"
  "CMakeFiles/las.dir/detail/writer/header.cpp.o"
  "CMakeFiles/las.dir/detail/writer/point.cpp.o"
  "CMakeFiles/las.dir/detail/writer/zipwriter.cpp.o"
  "CMakeFiles/las.dir/detail/writer/writer.cpp.o"
  "../bin/RelWithDebInfo/liblas.pdb"
  "../bin/RelWithDebInfo/liblas.dylib"
  "../bin/RelWithDebInfo/liblas.2.0.0.dylib"
)

# Per-language clean rules from dependency scanning.
FOREACH(lang CXX)
  INCLUDE(CMakeFiles/las.dir/cmake_clean_${lang}.cmake OPTIONAL)
ENDFOREACH(lang)
